#define GCONF_MAJOR_VERSION (2)
#define GCONF_MINOR_VERSION (12)
#define GCONF_MICRO_VERSION (0)
#define GCONF_CHECK_VERSION(major,minor,micro) \
	(GCONF_MAJOR_VERSION > (major) || \
	 (GCONF_MAJOR_VERSION == (major) && GCONF_MINOR_VERSION > (minor)) || \
	 (GCONF_MAJOR_VERSION == (major) && GCONF_MINOR_VERSION == (minor) && GCONF_MICRO_VERSION >= (micro)))
